diff --git a/core/modules/node/src/Tests/NodeAdminTest.php b/core/modules/node/src/Tests/NodeAdminTest.php
index 4785d71..ff1b63f 100644
--- a/core/modules/node/src/Tests/NodeAdminTest.php
+++ b/core/modules/node/src/Tests/NodeAdminTest.php
@@ -118,13 +118,14 @@ function testContentAdminSort() {
   function testContentAdminPages() {
     $this->drupalLogin($this->adminUser);
 
-    $nodes['published_page'] = $this->drupalCreateNode(array('type' => 'page'));
-    $nodes['published_article'] = $this->drupalCreateNode(array('type' => 'article'));
-    $nodes['unpublished_page_1'] = $this->drupalCreateNode(array('type' => 'page', 'uid' => $this->baseUser1->id(), 'status' => 0));
-    $nodes['unpublished_page_2'] = $this->drupalCreateNode(array('type' => 'page', 'uid' => $this->baseUser2->id(), 'status' => 0));
-
-    // Verify view, edit, and delete links for any content.
-    $this->drupalGet('admin/content');
+    $nodes['published_page'] = $this->drupalCreateNode(array('type' => 'page', 'title' => '01 first content'));
+    $nodes['published_article'] = $this->drupalCreateNode(array('type' => 'article', 'title' => '02 second content'));
+    $nodes['unpublished_page_1'] = $this->drupalCreateNode(array('type' => 'page', 'title' => '03 third content', 'uid' => $this->baseUser1->id(), 'status' => 0));
+    $nodes['unpublished_page_2'] = $this->drupalCreateNode(array('type' => 'page', 'title' => '04 fourth content', 'uid' => $this->baseUser2->id(), 'status' => 0));
+
+    // Verify view, edit, and delete links for any content. Use title sort to
+    // ensure the expected order.
+    $this->drupalGet('admin/content', array('query' => array('order' => 'title', 'sort' => 'asc')));
     $this->assertResponse(200);
 
     $node_type_labels = $this->xpath('//td[contains(@class, "views-field-type")]');
